# Changelog

This document covers main `dplib-py` releases:

## v0.7

- Updated to Data Package (v2-draft) ([#13](https://github.com/frictionlessdata/dplib-py/pull/13)).
- Rebased on stricter types for fields ([#14](https://github.com/frictionlessdata/dplib-py/pull/14)).

## v0.6

- Initial public release.
